@@ -13,7 +13,7 @@ classes <- sim.data$classes
 
 lambda <- msgl.lambda.seq(x, classes, alpha = .5, d = 100L, lambda.min = 0.01, standardize = TRUE)
 
-fit.qwe <- msgl(x, classes, lambda = lambda, intercept = FALSE)
+fit.qwe <- msgl(x, classes, lambda = lambda)
 
 res <- predict(fit.qwe, x)
 if(min(colSums(res$classes != classes)) > 0) stop()
