@@ -14,13 +14,7 @@ lambda <- msgl.lambda.seq(x, classes, alpha = .5, d = 25L, lambda.min = 0.05, st
 test <- replicate(2, 1:20, simplify = FALSE)
 train <- lapply(test, function(s) (1:length(classes))[-s])
 
-if(sgl.c.config()$omp.supported) {
-	threads = 2L
-} else {
-	threads = 1L
-}
-
-fit.sub <- msgl.subsampling(x, classes, alpha = .5, lambda = lambda, training = train, test = test, max.threads = threads)
+fit.sub <- msgl.subsampling(x, classes, alpha = .5, lambda = lambda, training = train, test = test)
 if(!all(fit.sub$classes[[1]] == fit.sub$classes[[2]])) stop()
 if(min(Err(fit.sub, type="count")) > 15) stop()
 
@@ -28,3 +22,19 @@ if(min(Err(fit.sub, type="count")) > 15) stop()
 features_stat(fit.sub)
 parameters_stat(fit.sub)
 
+###
+### Parallel tests
+###
+
+cl <- makeCluster(2)
+registerDoParallel(cl)
+
+fit.sub <- msgl.subsampling(x, classes, alpha = .5, lambda = lambda, training = train, test = test, use_parallel = TRUE)
+if(!all(fit.sub$classes[[1]] == fit.sub$classes[[2]])) stop()
+if(min(Err(fit.sub, type="count")) > 15) stop()
+
+# some navigation tests
+features_stat(fit.sub)
+parameters_stat(fit.sub)
+
+stopCluster(cl)
